==> phplist-2.10.5p0.tgz: lists/admin/lan/pt-br/import1.php <==
<?php 
$lan = array(

  'temp_dir_not_writeable' => 'O diret&oacute;rio tempor&aacute;rio para upload n&atilde;o permite grava&ccedil;&atilde;o, logo a importa&ccedil;&atilde;o ir&aacute; falhar',
  'select_list' => 'Por favor, selecione pelo menos uma lista',
  'too_large_inexistant' => 'O arquivo &eacute; muito grande ou n&atilde;o existe.',
  'none_specified' => 'Nenhum arquivo foi especificado. Talvez o arquivo seja muito grande?',
  'too_big' => 'O arquivo &eacute; muito grande, por favor, fa&ccedil;a uma divis&atilde;o em arquivos menores',
  'wrong_characters' => 'Erro na utiliza&ccedil;&atilde;o de caracteres: ',
  'signup_or_notify' => 'Por favor, escolha conectar imediatamente ou enviar um aviso',
  'unreadable' => 'N&atilde;o &eacute; poss&iacute;vel ler o arquivo !',
  'empty_file' => 'Houve algum erro durante o upload do arquivo. O arquivo recebido est&aacute; vazio. Talvez o arquivo seja muito grande ou n&atilde;o tem permiss&atilde;o de leitura.',
  'invalid_delimiter' => 'Alguns caracteres inv&aacute;lidos foram encontrados. Eles podem ser delimitadores. Por favor, verifique o arquivo e selecione o delimitador correto.',
  'import_user' => 'Importa&ccedil;&atilde;o de usu&aacute;rios existentes',
  'import_new_user' => 'Importa&ccedil;&atilde;o de novos usu&aacute;rios',
  'no_data_changed' => 'Nenhuma modifica&ccedil;&atilde;o nos dados de usu&aacute;rio',
  'lists_subscriptions' => 'Lista de inscri&ccedil;&otilde;es:',
  'was_subscribed' => 'Estava inscrito em:',
  'is_subscribed' => 'Agora est&aacute; inscrito em:',
  'not_subscribed' => 'N&atilde;o est&aacute; inscrito em nenhuma lista',
  'import_by' => 'Importar de ',
  'list' => 'lista',
  'lists' => 'listas',
  'new_email_was' => 'o novo email era',
  'new_emails_were' => 'os novos emails eram',
  'email_was' => 'o email era',
  'emails_were' => 'os emails eram',
  'import_more_emails' => 'Importar mais alguns emails',
  'add_list' => 'Adicionar uma lista',
  'test_output' => 'Testar resultados',
  'one_email_per_line' => 'Deve haver s&oacute; um email por linha.',
  'output_ok' => 'Se o resultado parece correto, voc&ecirc; pode',
  'back' => 'voltar',
  'resubmit' => ' reenviar realmente',
  'some_emails_exist' => 'alguns emails j&aacute; existiam na base de dados',
  'all_emails_exist' => 'Todos os emails j&aacute; existiam na base de dados.',
  'import_successful' => 'Importado(s) com succeso para a base de dados e adicionado(s) em',
  'subscribed' => 'inscrito em',
  'adding_users' => 'Adicionando usu&aacuter;ios &agrave; lista',
  'select_lists' => 'Selecione as listas nas quais voc&ecirc; adicionar&aacute; os emails',
  'no_lists' => 'Nenhuma lista dispon&iacute;vel, ',
  'info_emails_file' => 'O arquivo que voc&ecirc; fez upload deve conter os emails que voc&ecirc; quer adicionar a essas listas. Qualquer coisa depois do email ser&aacute; adicionada como atributo "Info" do usu&aacute;rio. Voc&ecirc; pode especificar os outros atributos desses usu&aacute;rios abaixo. <b>Aten&ccedil;&atilde;o</b>: o arquivo deve ser tipo texto. N&atilde;o fa&ccedil;a upload de arquivos bin&aacute;rios como Documentos do Word.',
  'emails_file' => 'Aquivo contendo emails:',
  'field_delimiter' => 'Campo Separador:',
  'tab_default' => '(o padr&atilde;o &eacute; TAB)',
  'record_delimiter' => 'Registrar Separador:',
  'line_break_default' => '(o padr&atilde;o &eacute; quebra de linha)',
  'info_test_output' => 'Se voc&ecirc; verificar o "Teste Resultados",  voc&ecirc; ver&aacute; a lista de emails categorizada na sua tela e a essas informa&ccedil;&otilde;es n&atilde;o ser&aacute; inseridas na base de dados. Isso &eacute; muito &uacute;til para verificar se o formato do seu arquivo est&aacute; correto. Ser&aacute; exibido somente os 50 primeiros registros.',
  'test_output' => 'Testar resultados:',
  'info_notification_email' => 'Se voc&ecirc; escolheu "enviar email de aviso", ser&aacute; enviada aos usu&aacute;rios que voc&ecirc; est&aacute; adicionando uma mensagem com o pedido de confirma&ccedil;&atilde;o da inscri&ccedil;&atilde;o, a qual eles devem responder. Isso &eacute; recomendado, pois identificar&aacute; os emails inv&aacute;lidosos.',
  'notification_email' => 'Enviar&nbsp;Aviso&nbsp;email&nbsp;',
  'confirmed_immediately' => 'Marcar como confirmado imediatamente&nbsp;',
  'import' => 'importar',
);
?>

==> phplist-2.10.14p1.tgz: lists/admin/lan/pt-br/import1.php <==
<?php 
$lan = array(
  'import is not available' => 'importa&ccedil;&atilde;o n&atilde;o est&aacute; dispon&iacute;vel',
  'temp_dir_not_writeable' => 'O diret&oacute;rio tempor&aacute;rio para upload n&atilde;o permite grava&ccedil;&atilde;o, logo a importa&ccedil;&atilde;o falhar&aacute;',
  'select_list' => 'Por favor, selecione pelo menos uma lista',
  'too_large_inexistant' => 'O arquivo &eacute; muito grande ou n&atilde;o existe.',
  'none_specified' => 'Nenhum arquivo foi especificado. Talvez o arquivo seja muito grande.',
  'too_big' => 'O arquivo &eacute; muito grande, por favor, fa&ccedil;a uma divis&atilde;o em arquivos menores',
  'wrong_characters' => 'Erro na utiliza&ccedil;&atilde;o de caracteres: ',
  'signup_or_notify' => 'Por favor, escolha conectar imediatamente ou enviar um aviso',
  'unreadable' => 'N&atilde;o &eacute; poss&iacute;vel ler o arquivo!',
  'empty_file' => 'Houve algum erro durante o upload do arquivo. O arquivo recebido est&aacute; vazio. Talvez o arquivo seja muito grande ou voc&ecirc; n&atilde;o tem permiss&atilde;o de leitura.',
  'invalid_delimiter' => 'Alguns caracteres inv&aacute;lidos foram encontrados. Eles podem ser delimitadores. Por favor, verifique o arquivo e selecione o delimitador correto.',
  'import_user' => 'Importa&ccedil;&atilde;o de usu&aacute;rios existentes',
  'import_new_user' => 'Importa&ccedil;&atilde;o de novos usu&aacute;rios',
  'no_data_changed' => 'Nenhuma modifica&ccedil;&atilde;o nos dados de usu&aacute;rio',
  'lists_subscriptions' => 'Lista de inscri&ccedil;&otilde;es:',
  'was_subscribed' => 'Estava inscrito em:',
  'is_subscribed' => 'Agora est&aacute; inscrito em:',
  'not_subscribed' => 'N&atilde;o est&aacute; inscrito em nenhuma lista',
  'import_by' => 'Importar de ',
  'list' => 'lista',
  'lists' => 'listas',
  'new_email_was' => 'o novo email era',
  'new_emails_were' => 'os novos emails eram',
  'email_was' => 'o email era',
  'emails_were' => 'os emails eram',
  'import_more_emails' => 'Importar mais alguns emails',
  'add_list' => 'Adicionar uma lista',
  'test_output' => 'Testar resultados',
  'one_email_per_line' => 'Somente um email por linha.',
  'output_ok' => 'Se o resultado parece correto, voc&ecirc; pode',
  'back' => 'voltar',
  'resubmit' => ' reenviar novamente',
  'some_emails_exist' => 'alguns emails j&aacute; existiam na base de dados',
  'all_emails_exist' => 'Todos os emails j&aacute; existiam na base de dados.',
  'import_successful' => 'Importado(s) com succeso para a base de dados e adicionado(s) em',
  'subscribed' => 'inscrito em',
  'adding_users' => 'Adicionando usu&aacute;rios &agrave; lista',
  'select_lists' => 'Selecione as listas nas quais voc&ecirc; adicionar&aacute; os emails',
  'no_lists' => 'Nenhuma lista dispon&iacute;vel, ',
  'info_emails_file' => 'O arquivo que voc&ecirc; fez upload deve conter os emails que voc&ecirc; quer adicionar a essas listas. Qualquer coisa depois do email ser&aacute; adicionada como atributo "Info" do usu&aacute;rio. Voc&ecirc; pode especificar os outros atributos desses usu&aacute;rios abaixo. <b>Aten&ccedil;&atilde;o</b>: o arquivo deve ser tipo texto. N&atilde;o fa&ccedil;a upload de arquivos bin&aacute;rios como Documentos do Word.',
  'emails_file' => 'Aquivo contendo emails:',
  'field_delimiter' => 'Campo Separador:',
  'tab_default' => '(o padr&atilde;o &eacute; TAB)',
  'record_delimiter' => 'Registrar Separador:',
  'line_break_default' => '(o padr&atilde;o &eacute; quebra de linha)',
  'info_test_output' => 'Se voc&ecirc; verificar o "Teste Resultados",  voc&ecirc; ver&aacute; a lista de emails categorizada na sua tela e essas informa&ccedil;&otilde;es n&atilde;o ser&aacute;o inseridas na base de dados. Isso &eacute; muito &uacute;til para verificar se o formato do seu arquivo est&aacute; correto. Ser&aacute; exibido somente os 50 primeiros registros.',
  'test_output' => 'Testar resultados:',
  'info_notification_email' => 'Se voc&ecirc; escolheu "enviar email de aviso", ser&aacute; enviada aos usu&aacute;rios que voc&ecirc; est&aacute; adicionando uma mensagem com o pedido de confirma&ccedil;&atilde;o da inscri&ccedil;&atilde;o, a qual eles devem responder. Isso &eacute; recomendado, pois identificar&aacute; os emails inv&aacute;lidos.',
  'notification_email' => 'Enviar&nbsp;Aviso&nbsp;email&nbsp;',
  'confirmed_immediately' => 'Marcar como confirmado imediatamente&nbsp;',
  'import' => 'importar',
);
?>
